@@ -1,11 +1,12 @@
 use crate::args::RunConfig;
 use crate::StickError::*;
-use chopstick::sufficient_disk_space;
+use chopstick::{max_buffer_size, sufficient_disk_space, ChunkedReader};
 pub use error::*;
-use std::fs::OpenOptions;
-use std::io::{Read, Write};
+use std::cmp::min;
+use std::fs::{File, OpenOptions};
+use std::io::Write;
 use std::path::Path;
-use std::{fs, io, process};
+use std::{fs, io, mem, process};
 
 mod args;
 mod error;
@@ -19,26 +20,35 @@ fn main() {
 
 fn _main() -> Result<()> {
     let mut config = RunConfig::new()?;
-    let mut buffer = Vec::new();
 
-    // Disk space check (only applies for retain)
-    if config.retain {
-        match total_part_size(&config.part_paths) {
-            Ok(required_space) => {
-                match sufficient_disk_space(&config.original_file, required_space) {
-                    Ok(true) => {
-                        if config.verbose {
-                            eprintln!("Enough disk space available for operation");
-                        }
+    // Disk space check
+    let space_needed = if !config.retain {
+        fs::metadata(&config.part_paths[0]).map(|md| md.len())
+    } else {
+        total_part_size(&config.part_paths)
+    };
+    match space_needed {
+        Ok(space_needed) => {
+            match sufficient_disk_space(&config.original_file, space_needed) {
+                Ok(true) => {
+                    if config.verbose {
+                        eprintln!(
+                            "Sufficient disk space available ({} needed)",
+                            bytesize::to_string(space_needed, true),
+                        );
                     }
-                    Ok(false) => return Err(InsufficientDiskSpace),
-                    Err(warn) => eprintln!("WARNING: {}", warn),
                 }
+                Ok(false) => return Err(InsufficientDiskSpace),
+                Err(warn) => eprintln!("WARNING: {warn}"),
             }
-            Err(why) => eprintln!("WARNING: unable to read part file sizes to check if space is available ({})", why),
         }
+        Err(why) => eprintln!("WARNING: unable to read part file sizes to check if space is available ({why})"),
     }
 
+    let buffer_size = min(config.part_size, max_buffer_size()) as usize;
+    // Buffer must be filled in order to be used in a PartialReader
+    let mut buffer: Vec<u8> = vec![0; buffer_size];
+
     let mut original_file = if !config.retain {
         // Check the original file doesn't already exist, so as not to
         // overwrite it if it does
@@ -100,35 +110,42 @@ fn _main() -> Result<()> {
         .part_paths
         .iter()
         .try_for_each(|part_path| -> Result<()> {
-            // Step 1: read part into memory
-            if !config.dry_run {
-                let mut part = OpenOptions::new()
-                    .read(true)
-                    .open(part_path)
+            // Step 1: read & write in chunks, controlled by ChunkedReader
+            let mut reader = if !config.dry_run {
+                let part = File::open(part_path)
                     .map_err(|err| ReadPart(part_path.clone(), err))?;
-                part.read_to_end(&mut buffer)
-                    .map_err(|err| ReadPart(part_path.clone(), err))?;
-            }
+                ChunkedReader::new(part, &mut buffer, config.verbose).into()
+            } else {
+                None
+            };
             if config.verbose {
-                eprintln!("Read {} into buffer", part_path.to_string_lossy());
+                // Extra new line for some nice spacing
+                eprintln!("\nReading from {}", part_path.to_string_lossy(),);
             }
 
-            // Step 2: write buffer to original file
             if !config.dry_run {
-                original_file
+                while let Some(bytes) = reader
                     .as_mut()
                     .unwrap()
-                    .write_all(&buffer)
-                    .map_err(WriteOriginal)?;
-            }
-            if config.verbose {
-                eprintln!("Appended buffer to original file");
+                    .read()
+                    .map_err(|err| ReadPart(part_path.clone(), err))?
+                {
+                    original_file
+                        .as_mut()
+                        .unwrap()
+                        .write_all(bytes)
+                        .map_err(WriteOriginal)?;
+                }
+                if config.verbose {
+                    eprintln!("Wrote buffer to original file");
+                }
+            } else if config.verbose {
+                eprintln!("[reading and writing happens]");
             }
 
-            // Step 3: clear buffer
-            buffer.clear();
-
-            // Step 4: delete part file
+            // Step 2: delete part file
+            // Drop reader so file is no longer open
+            mem::drop(reader);
             if !config.retain {
                 if !config.dry_run {
                     fs::remove_file(part_path)
@@ -143,13 +160,14 @@ fn _main() -> Result<()> {
         })?;
 
     if config.verbose && !config.dry_run {
-        eprintln!("Finished without error!");
+        // Extra new line for flair
+        eprintln!("\nFinished without error!");
     }
 
     Ok(())
 }
 
-fn total_part_size<P: AsRef<Path>>(paths: &[P]) -> Result<u64, io::Error> {
+fn total_part_size<P: AsRef<Path>>(paths: &[P]) -> io::Result<u64> {
     // All parts are the same size but the last one, so just multiply the size
     // of the first part by paths.len() - 1, then add the size of the last part
     debug_assert!(paths.len() >= 2);
