@@ -73,47 +73,82 @@ impl Split {
     }
 }
 
-struct TestScenario<const N: usize> {
-    temp_dir: TempDir,
-    original_file: ChildPath,
-    file_bytes: [u8; N],
+#[derive(Default)]
+struct TestScenarioBuilder<const N: usize> {
+    bytesize_formatted: bool,
+    persist: bool,
+    rng: Option<Box<dyn RngCore>>,
 }
 
-impl<const N: usize> TestScenario<N> {
-    fn new() -> Self {
-        Self::new_with_rng(&mut thread_rng())
+impl<const N: usize> TestScenarioBuilder<N> {
+    fn bytesize_formatted(mut self, yes: bool) -> Self {
+        self.bytesize_formatted = yes;
+        self
     }
 
-    fn new_with_rng<R: RngCore>(rng: &mut R) -> Self {
+    #[allow(dead_code)]
+    fn persist(mut self, yes: bool) -> Self {
+        self.persist = yes;
+        self
+    }
+
+    fn rng<R: RngCore + 'static>(mut self, rng: R) -> Self {
+        self.rng = Some(Box::new(rng));
+        self
+    }
+
+    fn build(self) -> TestScenario<N> {
         let temp_dir = TempDir::new().unwrap();
+        let temp_dir = if self.persist {
+            temp_dir.into_persistent()
+        } else {
+            temp_dir
+        };
         println!("Using temp dir {}", temp_dir.to_string_lossy());
         let original_file = temp_dir.child(FILE_NAME);
         let mut file_bytes = [0u8; N];
+
+        let mut rng = self.rng.unwrap_or_else(|| Box::new(thread_rng()));
         rng.fill_bytes(&mut file_bytes);
+
         original_file
             .write_binary(&file_bytes)
             .expect("Failed to write test bytes to temp file");
-        assert!(N > 1000, "N must be over 1000");
 
         TestScenario {
             temp_dir,
             original_file,
             file_bytes,
+            bytesize_formatted: self.bytesize_formatted,
         }
     }
+}
 
+struct TestScenario<const N: usize> {
+    temp_dir: TempDir,
+    original_file: ChildPath,
+    file_bytes: [u8; N],
+    bytesize_formatted: bool,
+}
+
+impl<const N: usize> TestScenario<N> {
     fn run_with(&self, split: Split) {
         println!(
-            "Chopping {} byte file into {} parts, {}B each",
-            N, split.num_parts, split.part_size,
+            "Chopping {N} byte file into {} parts, {} bytes each",
+            split.num_parts, split.part_size,
         );
+
+        let flag_val = match self.bytesize_formatted {
+            true => bytesize::to_string(split.flag_val(), true),
+            false => split.flag_val().to_string(),
+        };
+
         // Chop
         Command::cargo_bin("chop")
             .unwrap()
             .args(&[
                 split.flag,
-                // TODO: format as bytes if appropriate
-                &split.flag_val().to_string(),
+                &flag_val,
                 &self.original_file.path().to_string_lossy(),
             ])
             .unwrap()
@@ -127,9 +162,7 @@ impl<const N: usize> TestScenario<N> {
             .map(|n| (n + 1, (n * split.part_size) as usize))
             .for_each(|(part_no, file_bytes_offset)| {
                 let child_path = format!(
-                    "{}.{}{:0>width$}",
-                    FILE_NAME,
-                    EXTENSION_PREFIX,
+                    "{FILE_NAME}.{EXTENSION_PREFIX}{:0>width$}",
                     part_no,
                     width = digits(split.num_parts),
                 );
@@ -141,11 +174,16 @@ impl<const N: usize> TestScenario<N> {
                     self.file_bytes.len(),
                     file_bytes_offset + split.part_size as usize,
                 );
+                assert_eq!(
+                    part_bytes.len(),
+                    end_index - file_bytes_offset,
+                    "Part {part_no} of {} differs in length",
+                    split.num_parts
+                );
                 assert_eq!(
                     part_bytes.as_slice(),
                     &self.file_bytes[file_bytes_offset..end_index],
-                    "File contents differs in part {} of {}",
-                    part_no,
+                    "File contents differs in part {part_no} of {}",
                     split.num_parts,
                 );
             });
@@ -173,9 +211,15 @@ impl<const N: usize> TestScenario<N> {
     }
 }
 
+impl<const N: usize> Default for TestScenario<N> {
+    fn default() -> Self {
+        TestScenarioBuilder::<N>::default().build()
+    }
+}
+
 #[test]
 fn num_parts() {
-    let test = TestScenario::<FIVE_HUNGE_KIB>::new();
+    let test = TestScenario::<FIVE_HUNGE_KIB>::default();
     test.run_with(Split::from_num_parts(
         FIVE_HUNGE_KIB as u64,
         thread_rng().gen_range(10..=1000),
@@ -184,20 +228,37 @@ fn num_parts() {
 
 #[test]
 fn part_size() {
-    let test = TestScenario::<FIVE_HUNGE_KIB>::new();
+    let test = TestScenario::<FIVE_HUNGE_KIB>::default();
     test.run_with(Split::from_part_size(
         FIVE_HUNGE_KIB as u64,
         thread_rng().gen_range(10..=50 * 1024),
     ));
 }
 
+#[test]
+fn formatted_part_size() {
+    let test = TestScenarioBuilder::<FIVE_HUNGE_KIB>::default()
+        .bytesize_formatted(true)
+        .build();
+    // Ensure this is a factor of the file size else rounding errors will occur
+    let part_size = 125 * 1024;
+    println!("Using {} parts", bytesize::to_string(part_size, true));
+    test.run_with(Split::from_part_size(FIVE_HUNGE_KIB as u64, part_size));
+}
+
 #[test]
 #[ignore]
 fn something_specific() {
     // https://rust-random.github.io/book/guide-seeding.html#a-simple-number
-    let mut fixed_seed = Pcg64::seed_from_u64(14);
-    let test = TestScenario::<FIVE_HUNGE_KIB>::new_with_rng(&mut fixed_seed);
-    test.run_with(Split::from_num_parts(FIVE_HUNGE_KIB as u64, 986));
+    let fixed_seed = Pcg64::seed_from_u64(14);
+    let part_size = 50 * 1024;
+    println!("Using {} parts", bytesize::to_string(part_size, true));
+    let test = TestScenarioBuilder::<FIVE_HUNGE_KIB>::default()
+        .rng(fixed_seed)
+        .bytesize_formatted(true)
+        //.persist(true)
+        .build();
+    test.run_with(Split::from_part_size(FIVE_HUNGE_KIB as u64, part_size));
 }
 
 // TODO: large files, relative directories
